@@ -9,18 +9,18 @@ PYPROJ_TOML = 'pyproject.toml'
 @dataclasses.dataclass
 class Config:
     package: str
-    format: bool = True
+    format_strict: bool = False
     cache: bool = True
 
-    src_root: str = 'src'
+    openapi_root: str = 'src/openapi'
     gen_root: str = 'gen'
     patches: str = 'patches'
 
     def get_patches(self, project_root: Path) -> Path:
-        return project_root / self.src_root / self.patches
+        return project_root / self.openapi_root / self.patches
 
     def get_openapi(self, project_root: Path) -> Path:
-        return project_root / self.src_root / 'openapi.yaml'
+        return project_root / self.openapi_root / 'openapi.yaml'
 
 
 def load_config(project_root: Path) -> Config:
@@ -30,5 +30,5 @@ def load_config(project_root: Path) -> Config:
 
     with open(pyproj_path, 'br') as fb:
         pyproj = tomli.load(fb)
-        pyproj_dict = pyproj['tool']['lapidary']
-        return Config(**pyproj_dict)
+    pyproj_dict = pyproj['tool']['lapidary']
+    return Config(**pyproj_dict)
