@@ -17,8 +17,8 @@ class ClientClass:
 
 def get_client_class(openapi_model: openapi.OpenApiModel, module: ModulePath, resolver: ResolverFunc) -> ClientClass:
     functions = [
-        get_operation_func(op, method, url_path, module / 'paths' / op.operationId, resolver)
-        for url_path, path_item in openapi_model.paths.__root__.items()
+        get_operation_func(op, module, op.operationId, resolver)
+        for url_path, path_item in openapi_model.paths.items()
         for method, op in get_operations(path_item, True)
     ]
 
